@@ -15,8 +15,6 @@ use crate::{
 use anyhow::Error;
 use indexmap::IndexSet;
 use petgraph::EdgeDirection;
-#[cfg(feature = "concurrent")]
-use rayon::iter::ParallelIterator;
 use rustc_hash::{FxHashMap, FxHashSet, FxHasher};
 use std::{hash::BuildHasherDefault, sync::atomic::Ordering};
 use swc_atoms::js_word;
@@ -90,7 +88,7 @@ where
         ctx: &Ctx,
         entry_id: ModuleId,
         entry: &mut Modules,
-        all: &FxHashMap<ModuleId, Modules>,
+        all: &mut FxHashMap<ModuleId, Modules>,
     ) {
         self.run(|| {
             let injected_ctxt = self.injected_ctxt;
@@ -111,7 +109,7 @@ where
                     return Modules::empty(injected_ctxt);
                 }
 
-                all.get(id).cloned().unwrap_or_else(|| {
+                all.remove(id).unwrap_or_else(|| {
                     unreachable!(
                         "failed to merge into {}: module {} does not exist in the map",
                         entry_id, id
